genfs
A set of traits for implementing generic unix-style filesystems withour relying on an architecture or specific operating system.
Function definitions are mostly copied from the Rust standard library, with
some minor changes. This crate doesn’t depend on the standard library or the
alloc crate.
Documentation is mostly copied from the Rust standard library.
Structs
- A builder used to create directories in various manners.
- Options and flags which can be used to configure how a file is opened.
Enums
- Enumeration of possible methods to seek within an I/O object.
Traits
- Iterator over the entries in a directory.
- Entries returned by the
Diriterator. - A reference to an open file on the filesystem.
- Filesystem manipulation operations.